caellion-python-commons: tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder Class Reference

caellion-python-commons

Public Member Functions | Static Public Attributes | List of all members
tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder Class Reference

## Public Member Functions
def | test_cannot_init_twice (self)
def | test_build_empty_report (self)
def | test_build_basic_report (self)
def | test_build_basic_report_invalid_path_fails (self)
def | test_build_basic_report_none_path_fails (self)
def | test_build_basic_report_empty_path_fails (self)
def | test_build_basic_report_unknown_severity_fails (self)
def | test_build_basic_report_none_message_fails (self)
def | test_build_basic_report_none_empty_message_fails (self)
def | test_build_full_report_lineStart (self)
def | test_build_full_report_lineStartEnd (self)
def | test_build_full_report_lineStartEnd_fails_noStart (self)
def | test_build_full_report_lineStartEndcolStart (self)
def | test_build_full_report_lineStartEndcolStartEnd (self)
def | test_build_full_report_lineStartEndcolStartEnd_fails_noStart (self)
def | test_build_full_report_lineStartEndcolStartEndCatg (self)
def | test_build_full_report_lineStartEndcolStartEndCatgType (self)
def | test_build_full_report_lineStartEndcolStartEndCatgTypeDescr (self)
def | test_build_full_report_lineStartEndcolStartEndCatgTypeDescrPack (self)
def | test_build_full_report_lineStartEndcolStartEndCatgTypeDescrPackMod (self)
def | test_build_full_report (self)

## Static Public Attributes
| maxDiff = None

## Detailed Description

Definition at line 10 of file test_codeanalysis_reports.py.

## Member Function Documentation

## ◆ test_build_basic_report()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_basic_report | ( |  | self | ) |

Definition at line 30 of file test_codeanalysis_reports.py.

## ◆ test_build_basic_report_empty_path_fails()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_basic_report_empty_path_fails | ( |  | self | ) |

Definition at line 54 of file test_codeanalysis_reports.py.

## ◆ test_build_basic_report_invalid_path_fails()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_basic_report_invalid_path_fails | ( |  | self | ) |

Definition at line 40 of file test_codeanalysis_reports.py.

## ◆ test_build_basic_report_none_empty_message_fails()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_basic_report_none_empty_message_fails | ( |  | self | ) |

Definition at line 75 of file test_codeanalysis_reports.py.

## ◆ test_build_basic_report_none_message_fails()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_basic_report_none_message_fails | ( |  | self | ) |

Definition at line 68 of file test_codeanalysis_reports.py.

## ◆ test_build_basic_report_none_path_fails()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_basic_report_none_path_fails | ( |  | self | ) |

Definition at line 47 of file test_codeanalysis_reports.py.

## ◆ test_build_basic_report_unknown_severity_fails()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_basic_report_unknown_severity_fails | ( |  | self | ) |

Definition at line 61 of file test_codeanalysis_reports.py.

## ◆ test_build_empty_report()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_empty_report | ( |  | self | ) |

Definition at line 21 of file test_codeanalysis_reports.py.

## ◆ test_build_full_report()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_full_report | ( |  | self | ) |

Definition at line 259 of file test_codeanalysis_reports.py.

## ◆ test_build_full_report_lineStart()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_full_report_lineStart | ( |  | self | ) |

Definition at line 82 of file test_codeanalysis_reports.py.

## ◆ test_build_full_report_lineStartEnd()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_full_report_lineStartEnd | ( |  | self | ) |

Definition at line 92 of file test_codeanalysis_reports.py.

## ◆ test_build_full_report_lineStartEnd_fails_noStart()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_full_report_lineStartEnd_fails_noStart | ( |  | self | ) |

Definition at line 102 of file test_codeanalysis_reports.py.

## ◆ test_build_full_report_lineStartEndcolStart()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_full_report_lineStartEndcolStart | ( |  | self | ) |

Definition at line 112 of file test_codeanalysis_reports.py.

## ◆ test_build_full_report_lineStartEndcolStartEnd()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_full_report_lineStartEndcolStartEnd | ( |  | self | ) |

Definition at line 124 of file test_codeanalysis_reports.py.

## ◆ test_build_full_report_lineStartEndcolStartEnd_fails_noStart()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_full_report_lineStartEndcolStartEnd_fails_noStart | ( |  | self | ) |

Definition at line 142 of file test_codeanalysis_reports.py.

## ◆ test_build_full_report_lineStartEndcolStartEndCatg()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_full_report_lineStartEndcolStartEndCatg | ( |  | self | ) |

Definition at line 154 of file test_codeanalysis_reports.py.

## ◆ test_build_full_report_lineStartEndcolStartEndCatgType()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_full_report_lineStartEndcolStartEndCatgType | ( |  | self | ) |

Definition at line 173 of file test_codeanalysis_reports.py.

## ◆ test_build_full_report_lineStartEndcolStartEndCatgTypeDescr()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_full_report_lineStartEndcolStartEndCatgTypeDescr | ( |  | self | ) |

Definition at line 193 of file test_codeanalysis_reports.py.

## ◆ test_build_full_report_lineStartEndcolStartEndCatgTypeDescrPack()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_full_report_lineStartEndcolStartEndCatgTypeDescrPack | ( |  | self | ) |

Definition at line 214 of file test_codeanalysis_reports.py.

## ◆ test_build_full_report_lineStartEndcolStartEndCatgTypeDescrPackMod()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_build_full_report_lineStartEndcolStartEndCatgTypeDescrPackMod | ( |  | self | ) |

Definition at line 236 of file test_codeanalysis_reports.py.

## ◆ test_cannot_init_twice()

def tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.test_cannot_init_twice | ( |  | self | ) |

Definition at line 15 of file test_codeanalysis_reports.py.

## Member Data Documentation

## ◆ maxDiff

tests.test_codeanalysis_reports.TestCodeAnalysisReportsReportBuilder.maxDiff = None
| static

Definition at line 12 of file test_codeanalysis_reports.py.

The documentation for this class was generated from the following file:

- tests/test_codeanalysis_reports.py